
class LoadFieldConstants:

  ACCOUNT_ID = 'accountId'
  REFERENCE_NUMBER = 'referenceNumber'
  BOOKING_DATE = 'bookingDate'
  PICKUP_DATE = 'pickupDate'
  DELIVERY_DATE = 'deliveryDate'
  ORIGIN_CITY = 'originCity'
  ORIGIN_STATE = 'originState'
  DESTINATION_CITY = 'destinationCity'
  DESTINATION_STATE = 'destinationState'
  EQUIPMENT = 'equipment'
  CARRIER_ID = 'carrierId'
  ALL_IN_COST = 'allInCost'
  PRICE_TO_SHIPPER = 'priceToShipper'
  MILES = 'miles'
  CLIENT_ID = 'clientId'
  IMPORT_STATS_ID = 'importStatsId'
  CARRIER_CODE = 'carrierCode'
  ACCOUNT_EXEC_CODE = 'accountExecCode'
  ACCOUNT_EXEC_FIRST_NAME = 'accountExecFirstName'
  ACCOUNT_EXEC_LAST_NAME = 'accountExecLastName'
  CUSTOMER_CODE = 'customerCode'
  CUSTOMER_NAME = 'customerName'
  CARRIER_NAME = 'carrierName'
  CARRIER_REP_CODE = 'carrierRepCode'
  CARRIER_REP_FIRST_NAME = 'carrierRepFirstName'
  CARRIER_REP_LAST_NAME = 'carrierRepLastName'
  MARGIN = 'margin'
  RATE_TYPE = 'rateType'
  PROVIDER = 'provider'
  LINE_HAUL_COST = 'lineHaulCost'
  FUEL_PORTION = 'fuelPortion'
  ACCESSORIALS_INCLUDED = 'accessorialsIncluded'
  COMMODITY = 'commodity'
  WEIGHT = 'weight'
  ORIGIN_POSTCODE = 'originPostcode'
  DESTINATION_POSTCODE = 'destinationPostcode'
  REQUEST_ID = 'requestId'

class FileType:

  SINGLE_ROW = 'single_row'
  DUAL_ROW = 'dual_row'
  ALJEX_FILE = 'aljex_file'