import uuid

from dataclasses import dataclass, field

from cc_py_commons.transactions.equipment_class import EquipmentClass

@dataclass
class EquipmentMapping:

  equipment_class: EquipmentClass
  mapped_text: str
  # generated by server and returned
  id: uuid.UUID = field(default=None)